from setuptools import setup

setup(
    version='1.0',
    name='howdyho',
    packages=['howdyho'],
    description='while True:\n    print("хаудихо помоги")',
    author='Voronin9032',
    author_email='voronin9032n3@gmail.com',
    zip_safe=False
)
